#!/usr/bin/env python
# coding=UTF-8
# 
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: 0.py 2265 2010-02-21 19:16:26Z v13 $

__version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"

import gtk
import gobject
import hildon
from hildondesktop import *
from gtk import gdk
from math import pi
import cairo
import time

from portrait import FremantleRotation
from xdg.IconTheme import getIconPath

import config
import apps
import icon
from icon import Icon
from icons import Icons

def getIcon(name):
    ico=getIconPath(name, config.iconsize)
    ret=gtk.gdk.pixbuf_new_from_file_at_size(ico, config.iconsize,
	config.iconsize)

    return(ret)

#class IconGrid(gtk.Widget, FremantleRotation):
class IconGrid(object):	#(gobject.GObject):
    def __init__(self, isconfig=False):
#	self.__gobject_init__()

	self.size=0

	self.isconfig=isconfig

	self.icons=Icons(isconfig)

	self.setMode('l')

	# Maybe fix those:
#	w=(config.getSize() * config.iconsize) + \
#	    (config.getSize()) * config.iconspace
	#self.set_size_request(w, w)

#	self.setSize(config.getSize())
	self.setSize(4)

	self.lasticon=None  # The last icon that got selected

	self.reloadIcons()

    def connect(self, what, *args):
	if what in icon.signals:
	    self.icons.connect(what, *args)
	else:
	    super(IconGrid, self).connect(what, *args)

    def setSize(self, size):
	self.size=size
	self.icons.setSize(size)

    def setMode(self, mode):
	self.mode=mode
	if isinstance(self, gtk.Widget):
	    self.queue_draw()

    def iconAt(self, x, y):
	""" Get icon at coordinates x,y. X and Y are in pixels """

	w=config.iconsize + config.iconspace

	if self.mode=='l':
	    x2=int(x / w)
	    y2=int(y / w)
	else:
	    x2=self.size - int(y/w) - 1
	    y2=int(x/w)

	ret=self.get(x2,y2)

	return(ret)

    def get(self, x, y):
	ret=self.icons.get(x,y)

	return(ret)

    def _draw(self, cr, event):
	w=config.iconsize + config.iconspace
	for x,y in self.icons:
	    if self.mode=='l':
		x2=x * (config.iconsize + config.iconspace)
		y2=y * (config.iconsize + config.iconspace)
	    else:
		x2=y * (config.iconsize + config.iconspace)
		y2=(self.size-x-1) * (config.iconsize + config.iconspace)

	    # Only repaint the needed icons
	    rect=gdk.Rectangle(x2, y2, w, w)
	    t=rect.intersect(event.area)
	    if t.width==0 and t.height==0:
		continue

	    ico=self.icons.get(x,y)
	    ico.draw(cr, x2, y2, self.mode)

    def do_expose_event(self, event):
	cr=self.window.cairo_create()

	cr.rectangle(event.area.x, event.area.y,
	    event.area.width, event.area.height)

	cr.clip()

	self._draw(cr, event)

    def setLastIcon(self, icon):
	if icon==self.lasticon:
	    return

	if self.lasticon!=None:
	    self.lasticon.doCancel()
	    self.lasticon.invalidate(self.window)
	self.lasticon=icon

    def do_button_press_event(self, event):
	icon=self.iconAt(event.x, event.y)
	if icon==None:
	    return
#	rect=gdk.Rectangle(event.x,event.y,1,1)
#	rect=gdk.Rectangle(0, 0, 100, 100)
	icon.doPress()
	icon.invalidate(self.window)
	self.setLastIcon(icon)

#	gdk.Window.invalidate_rect(self.window, rect, True)

	return(True)

    def do_button_release_event(self, event):
	if self.lasticon!=None:
	    self.lasticon.invalidate(self.window)
	    self.lasticon.doRelease()

	self.setLastIcon(None)

	return(True)

    def do_leave_notify_event(self, event):
	self.setLastIcon(None)
	return(True)

    def do_pproperty_notify_event(self, event):
	icon=self.iconAt(event.x, event.y)
	if icon==None:
	    return
	icon.doCancel()
	icon.invalidate(self.window)
	return(True)

    def do_motion_notify_event(self, event):
	icon=self.iconAt(event.x, event.y)
	if self.lasticon==icon:
	    return(True)

	self.setLastIcon(None)
	icon.doCancel()
	icon.invalidate(self.window)
	return(True)

    def do_button_press_event_old(self, event):
	if event.type==gdk.BUTTON_PRESS:
	    if self.mode=='p':
		self.setMode('l')
	    else:
		self.setMode('p')
	    self.queue_draw()
	return True

    # For debugging
    def do_event1(self, event):
	print "event:", event, event.type

    def reloadIcons(self):
	self.icons.load()

#    def on_orientation_changed(self, orientation):
#	print "orch:", orientation
#	o=orientation[0]
#	self.setMode(o)

class IconGridWidget(IconGrid, gtk.Widget):
    def __init__(self, isconfig):
	IconGrid.__init__(self, isconfig)
	gtk.Widget.__init__(self)

	if isconfig:
	    w=4 * (config.iconsize + config.iconspace)
	else:
	    w=self.size * (config.iconsize + config.iconspace)

	self.set_size_request(w, w)

    def do_realize(self):
	screen=self.get_screen()
	self.set_colormap(screen.get_rgba_colormap())
	self.set_app_paintable(True)

	self.set_flags(self.flags() | gtk.REALIZED)

	self.window=gdk.Window(
	    self.get_parent_window(),
	    width=self.allocation.width,
	    height=self.allocation.height,
	    window_type=gdk.WINDOW_CHILD,
	    wclass=gdk.INPUT_OUTPUT,
	    event_mask=self.get_events() | gdk.EXPOSURE_MASK
		| gdk.BUTTON_PRESS_MASK 
		| gdk.BUTTON_RELEASE_MASK 
		| gdk.BUTTON_MOTION_MASK
		| gdk.POINTER_MOTION_MASK
		| gdk.POINTER_MOTION_HINT_MASK 
		| gdk.ENTER_NOTIFY_MASK
		| gdk.LEAVE_NOTIFY_MASK )

	self.window.set_user_data(self)
	self.style.attach(self.window)

#	self.style.set_background(self.window, gtk.STATE_NORMAL)
	self.window.move_resize(*self.allocation)

#	self.pixmap, mask = gtk.gdk.pixmap_create_from_xpm_d(
#	      self.window, self.style.bg[gtk.STATE_NORMAL], STAR_PIXMAP)
	
#	self.gc = self.style.fg_gc[gtk.STATE_NORMAL]

	#gtk.Widget.do_realize(self)
	#HomePluginItem.do_realize(self)

#	screen=self.get_screen()
#	self.set_colormap(screen.get_rgba_colormap())
#	self.set_app_paintable(True)

    def do_unrealize(self):
	#self.window.set_user_data(None)
	self.window.destroy()

#gobject.type_register(IconGrid)
gobject.type_register(IconGridWidget)


# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:

